#include "myQtCalendar.h"


addNote::addNote(QWidget *parent, Qt::WindowFlags flags) : QDialog(parent, flags)
{
	setWindowTitle("Editing a note:");
	setWindowModality(Qt::ApplicationModal);
	Ok_Clicked = false;
	Del_Clicked = false;
	textNote = new QLineEdit(this);
	noteText = new QLabel(this);
	noteText->setText("Note text:");
	myOKbutton = new QPushButton(this);
	myOKbutton->setText("OK");
	myDelButton = new QPushButton(this);
	myDelButton->setText("Delete note");
	connect(myOKbutton, SIGNAL(clicked(bool)), this, SLOT(endEdit()));
	connect(myDelButton, SIGNAL(clicked(bool)), this, SLOT(del_cl()));
	QVBoxLayout *mainLayout = new QVBoxLayout(this);
	mainLayout->addWidget(addNote::noteText);
	mainLayout->addWidget(addNote::textNote);
	mainLayout->addWidget(addNote::myOKbutton);
	mainLayout->addWidget(addNote::myDelButton);
	setLayout(mainLayout);
}

void addNote::endEdit()
{

	Ok_Clicked = true;
	close();
}

void addNote::del_cl()
{
	
	QMessageBox::StandardButton ret;
	ret = QMessageBox::question(this, "Deleting", "Do you really want to delete the selected?", QMessageBox::Ok | QMessageBox::Cancel);

	if (ret == QMessageBox::Ok)
		Del_Clicked = true;
	
	close();
}

void addNote::showEvent(QShowEvent * event)
{
	QDialog::showEvent(event);
	//adjustPosition(parentWidget());
}

addNote::~addNote()
{
	if (textNote)
	{
		delete (textNote);
		textNote = 0;
	}


	if (noteText)
	{
		delete (noteText);
		noteText = 0;
	}


	if (myOKbutton)
	{
		delete (myOKbutton);
		myOKbutton = 0;
	}

	if (myDelButton)
	{
		delete (myDelButton);
		myDelButton = 0;
	}

}

myQtCalendar::myQtCalendar(QWidget *parent)
	: QMainWindow(parent)
{
	ui.setupUi(this);

	QString plugins_patch = QCoreApplication::applicationDirPath();
	QStringList paths = QCoreApplication::libraryPaths();
	paths.append(plugins_patch + "/plugins/");
	QCoreApplication::setLibraryPaths(paths);

	QApplication::setStyle(QStyleFactory::create("fusion"));


	QString err = connect_db();

	if (!err.isEmpty())
	{
		QMessageBox::information(this, "Error", err);
		qApp->setQuitOnLastWindowClosed(true);
		exit(0);
	}

	QString my_setting = "Calendar (1.0) ";
	my_setting.append("base -  " + db.databaseName());
	setWindowTitle(my_setting);

	QMenu *fileMenu = ui.menuBar->addMenu("View");
	fileMenu->addAction(QIcon(":/icons/paste.png"), "Year", this, SLOT(view_year()));
	fileMenu->addAction(QIcon(":/icons/paste.png"), "Month", this, SLOT(view_month()));

	QToolButton *mycalendar = new QToolButton;
	mycalendar->setAutoRaise(true);
	mycalendar->setText("KALENDAR 0.1");
	mycalendar->setMinimumSize(25, 25);
	mycalendar->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);

	QLabel *lab = new QLabel;
	lab->setText("First day:");

	QComboBox *firstDay = new QComboBox;
	firstDay->addItem(QDate::longDayName(1), Qt::Monday);
	firstDay->addItem(QDate::longDayName(2), Qt::Tuesday);
	firstDay->addItem(QDate::longDayName(3), Qt::Wednesday);
	firstDay->addItem(QDate::longDayName(4), Qt::Thursday);
	firstDay->addItem(QDate::longDayName(5), Qt::Friday);
	firstDay->addItem(QDate::longDayName(6), Qt::Saturday);
	firstDay->addItem(QDate::longDayName(7), Qt::Sunday);

	QSpinBox *year = new QSpinBox;
	year->setMaximum(9999);
	year->setValue(QDate::currentDate().year());
	
	grid = new QGridLayout(ui.centralWidget);
	grid->setContentsMargins(1, 1, 1, 1);

	grid->addWidget(mycalendar, 0, 0, 1, 1);
	grid->addWidget(year, 0, 1, 1, 1);

	grid->addWidget(lab, 0, 2, 1, 1);
	grid->addWidget(firstDay, 0, 3, 1, 1);

	for (int i = 1; i <= 12; i ++)
	{
		CalendarGadget *gad = new CalendarGadget;
		Calendars.append(gad);
		gad->setMonth(i);

		connect(year, SIGNAL(valueChanged(int)), gad, SLOT(gotoYear(int)));
		connect(firstDay, SIGNAL(currentIndexChanged(int)), gad, SLOT(firstDayChanged(int)));
	}
		
	grid->addWidget(Calendars[0], 1, 0, 1, 1);
	grid->addWidget(Calendars[1], 1, 1, 1, 1);
	grid->addWidget(Calendars[2], 1, 2, 1, 2);
	grid->addWidget(Calendars[3], 2, 0, 1, 1);
	grid->addWidget(Calendars[4], 2, 1, 1, 1);
	grid->addWidget(Calendars[5], 2, 2, 1, 2);
	grid->addWidget(Calendars[6], 3, 0, 1, 1);
	grid->addWidget(Calendars[7], 3, 1, 1, 1);
	grid->addWidget(Calendars[8], 3, 2, 1, 2);
	grid->addWidget(Calendars[9], 4, 0, 1, 1);
	grid->addWidget(Calendars[10], 4, 1, 1, 1);
	grid->addWidget(Calendars[11], 4, 2, 1, 2);			
}


myQtCalendar::~myQtCalendar()
{
	qDeleteAll(Calendars.begin(), Calendars.end());
	Calendars.clear();
}

void myQtCalendar::view_month()
{
	QWidget *button = grid->itemAtPosition(0, 0)->widget();
	QWidget *year = grid->itemAtPosition(0, 1)->widget();
	QWidget *lab = grid->itemAtPosition(0, 2)->widget();
	QWidget *first = grid->itemAtPosition(0, 3)->widget();
	
	QWidget *widget1 = grid->itemAtPosition(1, 1)->widget();
	QWidget *widget2 = grid->itemAtPosition(1, 2)->widget();
	QWidget *widget3 = grid->itemAtPosition(2, 0)->widget();
	QWidget *widget4 = grid->itemAtPosition(2, 1)->widget();
	QWidget *widget5 = grid->itemAtPosition(2, 2)->widget();

	QWidget *widget6 = grid->itemAtPosition(3, 0)->widget();
	QWidget *widget7 = grid->itemAtPosition(3, 1)->widget();
	QWidget *widget8 = grid->itemAtPosition(3, 2)->widget();

	QWidget *widget9 = grid->itemAtPosition(4, 0)->widget();
	QWidget *widget10 = grid->itemAtPosition(4, 1)->widget();
	QWidget *widget11 = grid->itemAtPosition(4, 2)->widget();
	
	button->hide();
	year->hide();
	first->hide();
	lab->hide();
	
	widget1->hide();
	widget2->hide();
	widget3->hide();
	widget4->hide();
	widget5->hide();
	widget6->hide();
	widget7->hide();
	widget8->hide();
	widget9->hide();
	widget10->hide();
	widget11->hide();
}


void myQtCalendar::view_year()
{
	QWidget *button = grid->itemAtPosition(0, 0)->widget();
	QWidget *year = grid->itemAtPosition(0, 1)->widget();
	QWidget *lab = grid->itemAtPosition(0, 2)->widget();
	QWidget *first = grid->itemAtPosition(0, 3)->widget();
	
	QWidget *widget1 = grid->itemAtPosition(1, 1)->widget();
	QWidget *widget2 = grid->itemAtPosition(1, 2)->widget();
	QWidget *widget3 = grid->itemAtPosition(2, 0)->widget();
	QWidget *widget4 = grid->itemAtPosition(2, 1)->widget();
	QWidget *widget5 = grid->itemAtPosition(2, 2)->widget();

	QWidget *widget6 = grid->itemAtPosition(3, 0)->widget();
	QWidget *widget7 = grid->itemAtPosition(3, 1)->widget();
	QWidget *widget8 = grid->itemAtPosition(3, 2)->widget();

	QWidget *widget9 = grid->itemAtPosition(4, 0)->widget();
	QWidget *widget10 = grid->itemAtPosition(4, 1)->widget();
	QWidget *widget11 = grid->itemAtPosition(4, 2)->widget();

	button->show();
	year->show();
	first->show();
	lab->show();
	
	widget1->show();
	widget2->show();
	widget3->show();
	widget4->show();
	widget5->show();
	widget6->show();
	widget7->show();
	widget8->show();
	widget9->show();
	widget10->show();
	widget11->show();
}

QString myQtCalendar::connect_db()
{
	
	QString err = "";
	db = QSqlDatabase::addDatabase("QSQLITE");

	QString db_path = QCoreApplication::applicationDirPath() + "\\";
	//QMessageBox::information(this, "db_path", db_path);
	db.setDatabaseName(db_path + "calendar.db");
	//db.setDatabaseName("c:\\calendar.db");

	if (!db.open())
	{
		QSqlError er = db.lastError();		
		err = db_path + " " + er.driverText() + " - " + er.databaseText()+" "+"calendar.db";
	}

	return err;

}

CalendarModel::CalendarModel(QObject *parent) :QAbstractTableModel(parent)
{
	QDate curentDate = QDate::currentDate();
	month_ = curentDate.month();
	year_ = curentDate.year();
	firstDay = Qt::Monday;
}

int CalendarModel::rowCount(const QModelIndex & /*parent */) const
{
	return 6;
}

int CalendarModel::columnCount(const QModelIndex & /*parent */) const
{
	return 7;
}

void CalendarModel::get_notes_for_day(QDate noteDate)
{
	QSqlQuery myquery;
	QStringList notes;
	
	myquery.prepare("select NOTETEXT, ID from notes where NOTEDATE = :date");
	myquery.bindValue(":date", noteDate);

	if (myquery.exec())
	{
		while (myquery.next())			
			notes << myquery.value(0).toString();	
	}
	else
	{
		QString err = myquery.lastError().text();
		QMessageBox::information(0, "Error", err);
	}
	
	QFont font = QFont("Times", 15);
	QToolTip::setFont(font);	
	QToolTip::showText(QCursor::pos(), notes.join("\n"));

	QPalette palette = QToolTip::palette();
	palette.setColor(QPalette::ToolTipText, Qt::white);
	palette.setColor(QPalette::ToolTipBase, Qt::darkYellow);
	QToolTip::setPalette(palette);	
	
}

QVariant CalendarModel::data(const QModelIndex &index, int role) const
{	
	if (!index.isValid())
		return QVariant();
	
	int row = index.row();
	int column = index.column();
	int my_index = (7 * row) + column;

	if (role == Qt::DisplayRole)	
		return data_[my_index].day;

	if (role == Qt::ToolTipRole)
	{
		if (data_[my_index].notes_present)
		{
			QDate note_date(data_[my_index].year, data_[my_index].month, data_[my_index].day);
			get_notes_for_day(note_date);
		}
	}
			
	if (role == Qt::BackgroundColorRole)
	{
		
	if (data_[my_index].month != month_)		
			return QVariant(QColor(Qt::lightGray));
		
		if (data_[my_index].notes_present)
			return QVariant(QColor(Qt::yellow));

		if (data_[my_index].month == QDate::currentDate().month() && data_[my_index].day == QDate::currentDate().day())
			return QVariant(QColor(Qt::darkGreen));	
	}

	if (role == Qt::TextColorRole)
	{

		QDate weekend(data_[my_index].year, data_[my_index].month, data_[my_index].day);
	
		if (weekend.dayOfWeek() == 6 || weekend.dayOfWeek() == 7)
			return QVariant(QColor(Qt::red));
	}

	if (role == Qt::UserRole)
	{
		QDate fullDate(data_[my_index].year, data_[my_index].month, data_[my_index].day);
		return fullDate;
	}

	return QVariant();
}

QVariant CalendarModel::headerData(int section, Qt::Orientation orientation, int role) const
{
	if (role == Qt::DisplayRole)
	{
		if (orientation == Qt::Horizontal) 
		{
			int dayNum = section + firstDay;

			if (dayNum > 7)				
					dayNum = dayNum - 7;				
			
				return QDate::shortDayName(dayNum);
			}
	}
	
	return QVariant();	
}

QStringList CalendarModel::have_notes(QDate noteDateBegin, QDate noteDateEnd)
{
	QSqlQuery myquery;

	QStringList date_with_notes;
	date_with_notes.clear();

	myquery.prepare("SELECT notes.NOTEDATE, COUNT(notes.ID) AS count_notes FROM notes WHERE notes.NOTEDATE BETWEEN :noteDateBegin AND :noteDateEnd GROUP BY notes.NOTEDATE");
	myquery.bindValue(":noteDateBegin", noteDateBegin);
	myquery.bindValue(":noteDateEnd", noteDateEnd);

	if (myquery.exec())
	{
		int NOTEDATE = myquery.record().indexOf("NOTEDATE");
		int count_notes = myquery.record().indexOf("count_notes");

		while (myquery.next()) 
		{
			QString date = myquery.value(NOTEDATE).toString();
			date_with_notes << date;			
		}
	}

	else
	{
		QString err = myquery.lastError().text();
		QMessageBox::information(0, "Error", err);
	}


	return date_with_notes;
}

bool CalendarModel::day_found(QDate day, QStringList days_with_notes)
{
	QString my_day(day.toString("yyyy-MM-dd"));

	if (days_with_notes.contains(my_day))
		return true;
	
	return false;
}

void CalendarModel::updateModel()
{
	beginResetModel();

	data_.clear();

	QDate date(year_, month_, 1);
	QDate beginDate(date);
	
		beginDate = beginDate.addDays(firstDay - beginDate.dayOfWeek());
		
		if (beginDate.dayOfWeek() != 1 && beginDate.year() >= year_ && beginDate.month() >= month_) //for if firstday != 1
			beginDate = beginDate.addDays(-7);
	
	QDate endDate = beginDate.addDays(rowCount() * columnCount()-1);

	QStringList days_with_notes = have_notes(beginDate, endDate);

	while (beginDate <= endDate)
	{			
		Record rc = { beginDate.day(), beginDate.month(), beginDate.year(), day_found(beginDate, days_with_notes) };
		data_.push_back(rc);		
		beginDate = beginDate.addDays(1);
	}

	endResetModel();

	emit updated();
}

void CalendarModel::SetupFirstDayOfWeek(int day)
{
	firstDay = day;
	updateModel();
}

void CalendarModel::setMonth(int month)
{
	
	month_ = month;
	updateModel();
}

void CalendarModel::setYear(int year)
{
	
	year_ = year;
	updateModel();
}

int CalendarModel::month()const
{
	return month_;
}

int CalendarModel::year()const
{
	return year_;
}

CalendarGadget::CalendarGadget(QWidget *parent) : QWidget(parent)
{	

	MyCalendarModel = new CalendarModel(0);
	MyCalendarTable = new QTableView;
	MyCalendarTable->setModel(MyCalendarModel);
	my_addNote = new addNote(this);

	MyCalendarTable->setSelectionMode(QAbstractItemView::SingleSelection);

	MyCalendarTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
	MyCalendarTable->horizontalHeader()->setSectionsClickable(false);
	MyCalendarTable->verticalHeader()->setSectionResizeMode(QHeaderView::Stretch);
	MyCalendarTable->verticalHeader()->setSectionsClickable(false);

	connect(MyCalendarModel, SIGNAL(updated()), this, SLOT(model_updated()));
	connect(this, SIGNAL(do_update_model()), MyCalendarModel, SLOT(updateModel()));

	currentMonth = new QToolButton(this);
	currentMonth->setStyleSheet(QString::fromUtf8("background-color: rgb(209, 209, 209);"));

	currentMonth->setAutoRaise(true);
	QString MonthName = QDate::longMonthName(MyCalendarModel->month());
	currentMonth->setText(MonthName);
	currentMonth->setMinimumSize(25, 25);
	currentMonth->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
	connect(currentMonth, SIGNAL(clicked()), this, SLOT(selectMonths()));

	year = new QSpinBox(this);
	year->setMaximum(9999);
	year->setValue(MyCalendarModel->year());	
	connect(year, SIGNAL(valueChanged(int)), this, SLOT(selectYears(int)));

	prevMonth = new QPushButton(this);
	prevMonth->setIcon(QPixmap(":/res/arrow-left.png"));
	prevMonth->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);

	connect(prevMonth, SIGNAL(clicked()), this, SLOT(goToPrevMonth()));

	nextMonth = new QPushButton(this);
	nextMonth->setIcon(QPixmap(":/res/arrow-right.png"));
	nextMonth->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);

	connect(nextMonth, SIGNAL(clicked()), this, SLOT(goToNextMonth()));

	QVBoxLayout *verticalLayout = new QVBoxLayout();
	QHBoxLayout *horizontalLayout = new QHBoxLayout();

	horizontalLayout->setContentsMargins(0, 0, 0, 0);
	horizontalLayout->setSpacing(2);

	verticalLayout->setContentsMargins(0, 0, 0, 0);
	verticalLayout->setSpacing(6);

	horizontalLayout->addWidget(prevMonth);
	horizontalLayout->addWidget(currentMonth);
	horizontalLayout->addWidget(year);

	horizontalLayout->addWidget(nextMonth);

	verticalLayout->addLayout(horizontalLayout);
	verticalLayout->addWidget(MyCalendarTable);

	setLayout(verticalLayout);

	setContextMenuPolicy(Qt::CustomContextMenu);
	connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(customContextMenuRequested(QPoint)));
}

void CalendarGadget::resizeEvent(QResizeEvent *event)
{
	/*for (int i = 0; i < MyCalendarTable->model()->columnCount(); i++)
		MyCalendarTable->setColumnWidth(i, MyCalendarTable->width() / 7.5);

	for (int i = 0; i < MyCalendarTable->model()->rowCount(); i++)
		MyCalendarTable->setRowHeight(i, MyCalendarTable->height() / 7);*/


	QWidget::resizeEvent(event);
}

CalendarGadget::~CalendarGadget()
{
	if (MyCalendarModel)
	{
		delete MyCalendarModel;
		MyCalendarModel = 0;
	}

	if (MyCalendarTable)
	{
		delete MyCalendarTable;
		MyCalendarTable = 0;
	}

	if (currentMonth)
	{
		delete currentMonth;
		currentMonth = 0;
	}

	if (prevMonth)
	{
		delete prevMonth;
		prevMonth = 0;
	}

	if (nextMonth)
	{
		delete nextMonth;
		nextMonth = 0;
	}

	if (year)
	{
		delete year;
		year = 0;
	}

	if (my_addNote)
	{
			delete my_addNote;
			my_addNote = 0;
	}
}

void CalendarGadget::model_updated()
{
	QString MonthName = QDate::longMonthName(MyCalendarModel->month());
	currentMonth->setText(MonthName);
	year->setValue(MyCalendarModel->year());
}

void CalendarGadget::goToNextMonth()
{	
	int month = MyCalendarModel->month();

	if (month >= 12)
		month = 0;

	MyCalendarModel->setMonth(month + 1);	
}

void CalendarGadget::goToPrevMonth()
{
	int month = MyCalendarModel->month();

	if (month <= 1)
		month = 13;

	MyCalendarModel->setMonth(month - 1);
}

void CalendarGadget::selectYears(int year)
{	
	MyCalendarModel->setYear(year);
}

void CalendarGadget::selectMonths()
{
	monthMenu = new QMenu(this);

	for (int i = 1; i <= 12; i++)
	{
		QAction *action = monthMenu->addAction(QDate::longMonthName(i));
		connect(action, SIGNAL(triggered()), this, SLOT(goToMonth()));
	}

	monthMenu->exec(QCursor::pos());
}

void CalendarGadget::setMonth(int month)
{
	MyCalendarModel->setMonth(month);
}

void CalendarGadget::goToMonth()
{	
	 QAction *action = qobject_cast<QAction *>(sender());
	 if (action)
		{
			int month = QDate::fromString(action->text(), "MMMM").month();
			MyCalendarModel->setMonth(month);
		}
}

void CalendarGadget::customContextMenuRequested(const QPoint &)
{	
	QDate selectedDate = getSelectedDay();

	if (selectedDate.month() == MyCalendarModel->month())
	{
		QMenu *menu = new QMenu(this);
		QAction *addAction = menu->addAction(QIcon(":/res/new_note.png"), tr("Add new note"), this, SLOT(add_note()));
		QAction *addAction1 = menu->addAction(QIcon(":/res/edit_note.png"), tr("Editing a note"), this, SLOT(edit_notes()));
		QAction *addAction2 = menu->addAction(QIcon(":/res/view_note.png"), tr("Viewing notes"), this, SLOT(view_notes()));
		menu->exec(QCursor::pos());
	}
	else	
		QMessageBox::information(this, "Error", "Only the days of the current month are edited!");
	
}

QDate CalendarGadget::getSelectedDay()
{
	const QModelIndex index = MyCalendarTable->selectionModel()->currentIndex();
	return index.data(Qt::UserRole).toDate();
}

void CalendarGadget::SetNote(QString noteText, QDate noteDate, QTime NoteTime)
{
	QSqlQuery myquery;
	myquery.prepare("INSERT INTO notes (NOTETEXT, NOTEDATE, NOTETIME) VALUES (?,?,?)");

	myquery.bindValue(0, noteText);
	myquery.bindValue(1, noteDate);
	myquery.bindValue(2, NoteTime);

	if (myquery.exec())
		myquery.clear();
		
	else
	{
		QString err = myquery.lastError().text();
		QMessageBox::information(this, "Error", err);
	}
}

void CalendarGadget::UpdateNote(QString noteText, QDate noteDate, QTime NoteTime, int ID)
{
	QSqlQuery query;
	query.prepare("UPDATE notes SET NOTETEXT = :NOTETEXT, NOTEDATE = :NOTEDATE, NOTETIME = :NOTETIME WHERE ID = :myid");

	query.bindValue(":NOTETEXT", noteText);
	query.bindValue(":NOTEDATE", noteDate);
	query.bindValue(":NOTETIME", NoteTime);
	query.bindValue(":myid", ID);

	if (query.exec())
		query.clear();

	else
	{
		QString err = query.lastError().text();
		QMessageBox::information(this, "Error", err);
	}
}

void CalendarGadget::DeleteNote(int ID)
{
	QSqlQuery query;
	query.prepare("DELETE FROM notes WHERE ID = :myid");
	query.bindValue(":myid", ID);

	if (query.exec())
		query.clear();

	else
	{
		QString err = query.lastError().text();
		QMessageBox::information(this, "Error", err);
	}
}

void CalendarGadget::add_note()
{
	
	QDate selectedDate = getSelectedDay();
	my_addNote->Ok_Clicked = false;
	my_addNote->Del_Clicked = false;
	my_addNote->myDelButton->hide();
	my_addNote->setWindowTitle(selectedDate.toString());
	my_addNote->noteText->setText("Note text:");
	my_addNote->textNote->setText("Enter note text:");
	my_addNote->textNote->selectAll();
	my_addNote->exec();

	if (my_addNote->Ok_Clicked && !my_addNote->textNote->text().isEmpty())		
		SetNote(my_addNote->textNote->text(), selectedDate, QTime::currentTime());

	do_update_model();
		
}

QVector<CalendarGadget::my_data> CalendarGadget::GetNotes(QDate noteDate)
{
	QSqlQuery myquery;
	
	QVector<my_data> noteData;

	myquery.prepare("select NOTETEXT, ID from notes where NOTEDATE = :date");
	myquery.bindValue(":date", noteDate);

	if (myquery.exec())
	{
		while (myquery.next())
		{
			my_data rc = { myquery.value(0).toString(), myquery.value(1).toString() };
			noteData.push_back(rc);
		}
	}
	else
	{
		QString err = myquery.lastError().text();
		QMessageBox::information(this, "Error", err);
	}

	return noteData;
}

void CalendarGadget::edit_note()
{

	QDate selectedDate = getSelectedDay();	
	QAction *action = qobject_cast<QAction *>(sender());
	if (action)
	{
		QString note = action->text();
		int id = action->data().toInt();
		my_addNote->Ok_Clicked = false;
		my_addNote->Del_Clicked = false;
		my_addNote->myDelButton->show();
		my_addNote->setWindowTitle(selectedDate.toString());
		my_addNote->noteText->setText("Note text:");
		my_addNote->textNote->setText(note);
		my_addNote->textNote->selectAll();
		my_addNote->exec();

		if (my_addNote->Ok_Clicked && !my_addNote->textNote->text().isEmpty())
			UpdateNote(my_addNote->textNote->text(), selectedDate, QTime::currentTime(), id);

		if (my_addNote->Del_Clicked)
			DeleteNote(id);
	}

	do_update_model();

}

void CalendarGadget::view_notes()
{
	QDate selectedDate = getSelectedDay();
	QVector<my_data> noteData = GetNotes(selectedDate);
	QMenu menu;

	for (int i = 0; i < noteData.count(); i++)
	{		
		QString noteText = noteData[i].textNote;
		menu.addAction(QIcon(":/res/note.png"), noteText);
		menu.addSeparator();
	}

	menu.exec(QCursor::pos());
}

void CalendarGadget::edit_notes()
{
	
	QDate selectedDate = getSelectedDay();
	QVector<my_data> noteData = GetNotes(selectedDate);
	QMenu menu;

	for (int i = 0; i < noteData.count(); i++)
	{
		QString noteIndex = noteData[i].ID;
		QString noteText = noteData[i].textNote;

		QAction *action = menu.addAction(QIcon(":/res/note.png"), noteText);
		action->setData(noteIndex);
		connect(action, SIGNAL(triggered()), this, SLOT(edit_note()));
	}

	menu.exec(QCursor::pos());

}

void CalendarGadget::gotoYear(int year)
{
	selectYears(year);
}

void CalendarGadget::firstDayChanged(int day)
{
	MyCalendarModel->SetupFirstDayOfWeek(day+1);
}




