#pragma once

#include <QtWidgets/QMainWindow>
#include "ui_myQtCalendar.h"
#include <QTextCodec>
#include <QAbstractTableModel>

#include <QVBoxLayout> 
#include <QDate> 
#include <QLabel>
#include <QPushButton> 
#include <QMenu> 
#include <QSpinBox> 
#include <QTableView>
#include <QToolButton> 
#include <QCommandLinkButton> 
#include <QComboBox>
#include <QStandardPaths> 
#include <QMessageBox> 
#include <QStyleFactory>

#include <QSqlDatabase>
#include <QSqlError>
#include <QSqlQuery>
#include <QSqlRecord>

#include <QTimeEdit>
#include <QLineEdit>
#include <QCheckBox>
#include <QToolTip> 



class addNote :public QDialog
{
	Q_OBJECT

public:
	~addNote();
	addNote(QWidget *parent = 0, Qt::WindowFlags flags = 0);
	QLineEdit   *textNote;
	QLabel      *noteText;
	bool		Ok_Clicked;
	bool		Del_Clicked;
	QPushButton *myDelButton;

private:
	QPushButton *myOKbutton;
	

protected:
	void showEvent(QShowEvent * event);

	private slots:
	void endEdit();
	void del_cl();
};

class CalendarModel : public QAbstractTableModel
{
	Q_OBJECT
public:
	CalendarModel(QObject *parent);
	int rowCount(const QModelIndex &parent = QModelIndex()) const override;
	int columnCount(const QModelIndex &parent = QModelIndex()) const override;
	QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;	
	QVariant headerData(int section, Qt::Orientation orientation, int role) const override;

	void setMonth(int month);
	void setYear(int year);
	void SetupFirstDayOfWeek(int day);
	QStringList have_notes(QDate, QDate);
	static void get_notes_for_day(QDate);
	bool day_found(QDate, QStringList);

	int month() const;
	int year()const;

	struct Record
	{
		int day; 
		int month;
		int year;
		bool notes_present;
	};


private:
	
	int month_; 
	int year_;  

	QVector<Record> data_;

protected:
	int firstDay;
	
public slots:
	void updateModel();


signals:
	void updated();
	
};

class CalendarGadget : public QWidget
{

	Q_OBJECT

public:
	CalendarGadget(QWidget *parent = 0);
	~CalendarGadget();

	QTableView *MyCalendarTable;
	CalendarModel *MyCalendarModel;
	QDate getSelectedDay();
	void setMonth(int month);
	QToolButton *currentMonth;
	QPushButton *prevMonth;
	QPushButton *nextMonth;
	QSpinBox *year;
	QMenu *monthMenu;

	struct my_data
	{
		QString textNote;
		QString ID;
	};


	QVector<my_data> GetNotes(QDate noteDate);
	void SetNote(QString noteText, QDate noteDate, QTime NoteTime);
	void UpdateNote(QString noteText, QDate noteDate, QTime NoteTime, int ID);
	void DeleteNote(int ID);

private:
	addNote *my_addNote;

	private slots:
		void model_updated();
		void goToPrevMonth();
		void goToNextMonth();
		void selectYears(int year);
		void selectMonths();
		void goToMonth();
		void customContextMenuRequested(const QPoint &);
		void add_note();
		void edit_notes();
		void edit_note();
		void view_notes();

  public slots:
		void gotoYear(int year);
		void firstDayChanged(int day);

protected:
	void resizeEvent(QResizeEvent *event);

signals:
	void do_update_model();

};

class myQtCalendar : public QMainWindow
{
	Q_OBJECT

public:
	myQtCalendar(QWidget *parent = Q_NULLPTR);
	QString connect_db();
	QSqlDatabase db;
	~myQtCalendar();

private:
	Ui::myQtCalendarClass ui;


protected:
	QGridLayout *grid;
	QVector <CalendarGadget*> Calendars;

	private slots:
	void view_month();
	void view_year();

};



